@@ -1,8 +1,7 @@
-{-# LANGUAGE GeneralizedNewtypeDeriving
-           , FlexibleInstances
-           , MultiParamTypeClasses
-           , CPP
-  #-}
+{-# LANGUAGE CPP                        #-}
+{-# LANGUAGE FlexibleInstances          #-}
+{-# LANGUAGE GeneralizedNewtypeDeriving #-}
+{-# LANGUAGE MultiParamTypeClasses      #-}
 
 -----------------------------------------------------------------------------
 -- |
@@ -56,32 +55,23 @@ module Control.Monad.StateStack
 
        ) where
 
-#if __GLASGOW_HASKELL__ < 710
-import Data.Monoid
-import Control.Applicative
-#endif
-import Control.Arrow (second)
-import Control.Monad.Identity
-import qualified Control.Monad.State as St
-import Control.Arrow (first, (&&&))
+import           Control.Arrow                     (second)
+import           Control.Arrow                     (first, (&&&))
+import qualified Control.Monad.State               as St
 
-import Control.Monad.Trans
-import Control.Monad.Trans.Cont
-import Control.Monad.Trans.Except
-import Control.Monad.Trans.Identity
-import Control.Monad.Trans.List
-import Control.Monad.Trans.Maybe
-import Control.Monad.Trans.Reader (ReaderT)
-import Control.Monad.Trans.State.Lazy as Lazy
-import Control.Monad.Trans.State.Strict as Strict
-import Control.Monad.Trans.Writer.Lazy as Lazy
-import Control.Monad.Trans.Writer.Strict as Strict
+import           Control.Monad.Identity
+import           Control.Monad.Trans
+import           Control.Monad.Trans.Cont
+import           Control.Monad.Trans.Except
+import           Control.Monad.Trans.Maybe
+import           Control.Monad.Trans.Reader        (ReaderT)
+import           Control.Monad.Trans.State.Lazy    as Lazy
+import           Control.Monad.Trans.State.Strict  as Strict
+import           Control.Monad.Trans.Writer.Lazy   as Lazy
+import           Control.Monad.Trans.Writer.Strict as Strict
 
-import qualified Control.Monad.Cont.Class as CC
--- import qualified Control.Monad.Error.Class as EC
-import qualified Control.Monad.State.Class as StC
--- import qualified Control.Monad.Reader.Class as RC
-import qualified Control.Monad.IO.Class as IC
+import qualified Control.Monad.Cont.Class          as CC
+import qualified Control.Monad.IO.Class            as IC
 
 
 ------------------------------------------------------------
@@ -162,10 +152,6 @@ instance MonadStateStack s m => MonadStateStack s (IdentityT m) where
   save    = lift save
   restore = lift restore
 
-instance MonadStateStack s m => MonadStateStack s (ListT m) where
-  save    = lift save
-  restore = lift restore
-
 instance MonadStateStack s m => MonadStateStack s (MaybeT m) where
   save    = lift save
   restore = lift restore
